@@ -85,13 +85,13 @@ import Text.Pandoc.Shared (ObfuscationMethod(..))
 import Text.XHtml hiding ( (</>), dir, method, password, rev )
 import Text.Highlighting.Kate
 import Data.Maybe (isNothing)
-import Codec.Binary.UTF8.String (encodeString)
 import System.FilePath
 import Control.Monad.State
 import Control.Exception (throwIO, catch)
-import Network.URI (isUnescapedInURI, escapeURIString)
 import qualified Data.ByteString as S (concat) 
 import qualified Data.ByteString.Lazy as L (toChunks, fromChunks)
+import Network.URL (encString)
+import Network.URI (isUnescapedInURI)
 
 --
 -- ContentTransformer runners
@@ -446,7 +446,7 @@ addMathSupport c = do
   updateLayout $ \l ->
     case mathMethod conf of
          JsMathScript -> addScripts l ["jsMath/easy/load.js"]
-         MathML       -> addScripts l ["MathMLInHTML.js"]
+         MathML       -> addScripts l ["MathMLinHTML.js"]
          RawTeX       -> l
   return c
 
@@ -507,7 +507,7 @@ convertWikiLinks x = x
 
 -- | Derives a URL from a list of Pandoc Inline elements.
 inlinesToURL :: [Inline] -> String
-inlinesToURL = escapeURIString isUnescapedInURI  . encodeString . inlinesToString
+inlinesToURL = encString False isUnescapedInURI . inlinesToString
 
 -- | Convert a list of inlines into a string.
 inlinesToString :: [Inline] -> String
